package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.PwddicMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IPwddic;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EncodingDetect;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/PwddicService.class */
public class PwddicService implements IPwddic {
    private PwddicMapper pwddicMapper = (PwddicMapper) InstanceUtil.newDaoInstance(PwddicMapper.class);

    public int searchCount(HttpSession session, String name, String content, Integer type) throws Exception {
        return this.pwddicMapper.searchCount(name, content, type, DataRule.getRuleWhere(session, "t_pwd_dic"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, String content, Integer type, Integer offset, Integer limit) throws Exception {
        return this.pwddicMapper.search(name, content, type, offset, limit, DataRule.getRuleWhere(session, "t_pwd_dic"));
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.pwddicMapper.getCountTaskByKid(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("此弱口令字典已被任务引用，请在任务管理中移除引用关系！");
        }
        Map<String, Object> kwdemp = this.pwddicMapper.getTemplateById(id);
        String path = ObjectUtil.getString(kwdemp.get("path"), "");
        if (StringUtils.isNotBlank(path)) {
            File f = new File(Constant.PWDDIC_DIC, path);
            f.delete();
        }
        Integer vcount = Integer.valueOf(this.pwddicMapper.delete(id, version, DataRule.getRuleWhere(session, "t_pwd_dic")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public void insert(HttpSession session, String name, String content, Integer type) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.pwddicMapper.getCountByName(name, (Integer) null, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("字典名称已存在！");
        }
        String[] lines = content.split("\n");
        StringBuilder sb = new StringBuilder();
        for (String line : lines) {
            if (!"".equals(line) && line.length() <= 100) {
                sb.append("\n").append(line);
            }
        }
        if (sb.length() == 0) {
            throw new UEException("字典内容格式错误，单个字典内容长度不能超过100个字符！");
        }
        String content2 = sb.deleteCharAt(0).toString();
        String fname = "user/" + System.nanoTime() + ".txt";
        if (content2.length() > 500) {
            File f = new File(Constant.PWDDIC_DIC, fname);
            try {
                FileUtils.writeStringToFile(f, content2, "UTF-8");
                this.pwddicMapper.insert(name, String.valueOf(content2.substring(0, 100)) + "...", fname, uid, type);
                return;
            } catch (Exception e) {
                f.delete();
                throw e;
            }
        }
        this.pwddicMapper.insert(name, content2, "", uid, type);
    }

    public void update(HttpSession session, Integer id, String name, String content, Integer type, Integer version) throws Exception {
        Integer count = this.pwddicMapper.getCountByName(name, id, ((User) session.getAttribute("userInfo")).getId());
        if (count != null && count.intValue() > 0) {
            throw new UEException("字典名称已存在");
        }
        String[] lines = content.split("\n");
        StringBuilder sb = new StringBuilder();
        for (String line : lines) {
            if (!"".equals(line) && line.length() <= 100) {
                sb.append("\n").append(line);
            }
        }
        if (sb.length() == 0) {
            throw new UEException("字典内容格式错误，单个字典内容长度不能超过100个字符！");
        }
        String content2 = sb.deleteCharAt(0).toString();
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        String rule = DataRule.getRuleWhere(session, "t_pwd_dic");
        Map<String, Object> kwdmap = this.pwddicMapper.getTemplateById(id);
        String path = ObjectUtil.getString(kwdmap.get("path"), "");
        File f = new File(Constant.PWDDIC_DIC, path);
        if (content2.length() > 500) {
            Integer vcount = Integer.valueOf(this.pwddicMapper.update(id, name, String.valueOf(content2.substring(0, 100)) + "...", path, type, version, rule, uid));
            if (vcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
            FileUtils.writeStringToFile(f, content2, "UTF-8");
            return;
        }
        Integer vcount2 = Integer.valueOf(this.pwddicMapper.update(id, name, content2, "", type, version, rule, uid));
        if (vcount2.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        if (f.exists()) {
            f.delete();
        }
    }

    public Map<String, Object> getTemplateById(Integer id) throws Exception {
        return this.pwddicMapper.getTemplateById(id);
    }

    public Map<String, Object> pwddicExp(Integer id) throws Exception {
        Map<String, Object> result = this.pwddicMapper.getTemplateById(id);
        String path = ObjectUtil.getString(result.get("path"), (String) null);
        File f = new File(Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + ".txt");
        if (path == null) {
            String content = ObjectUtil.getString(result.get("content"), "");
            FileUtils.writeStringToFile(f, content, "UTF-8");
        } else {
            FileUtils.copyFile(new File(Constant.PWDDIC_DIC, path), f);
        }
        Map<String, Object> r = new HashMap<>();
        r.put("file", f);
        r.put("name", result.get("name"));
        return r;
    }

    public void pwddicImp(HttpSession session, String onlyName, String realName, Integer id, Integer version, Integer type) throws Exception {
        File f = new File(Constant.TEMP_DIR, onlyName);
        if (f.exists() && f.length() == 0) {
            throw new UEException("请勿上传空文件！");
        }
        String name = realName.substring(0, realName.lastIndexOf("."));
        String content = FileUtils.readFileToString(f, EncodingDetect.getJavaEncode(f));
        if (StringUtils.isNotBlank(name)) {
            if (id == null || version == null) {
                insert(session, name, content, type);
            } else {
                update(session, id, name, content, type, version);
            }
        }
    }

    public List<Map<String, Object>> getKeyName() throws Exception {
        return this.pwddicMapper.getKeyName();
    }

    public Map<String, Object> getIdByName(HttpSession session, String name) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        return this.pwddicMapper.getIdByName(name, uid);
    }

    public List<Map<String, Object>> getPwdByType(Integer type) throws Exception {
        return this.pwddicMapper.getPwdByType(type);
    }

    public Map<String, Object> getPwdGroupById(Integer id) throws Exception {
        return this.pwddicMapper.getPwdGroupById(id);
    }

    public List<Map<String, Object>> getPwdGroups() throws Exception {
        return this.pwddicMapper.getPwdGroups();
    }

    public int updateGroup(HttpSession session, Integer id, String name, Integer upid, Integer ppid, Integer version) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        if (this.pwddicMapper.getCountByGroupName(name, id, user.getId()).intValue() > 0) {
            throw new UEException("组合字典【" + name + "】已存在");
        }
        Integer vcount = Integer.valueOf(this.pwddicMapper.updateGroup(id, name, upid, ppid, version, DataRule.getRuleWhere(session, "t_pwd_group"), user.getId()));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        return vcount.intValue();
    }

    public int insertGroup(HttpSession session, String name, Integer upid, Integer ppid) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        if (this.pwddicMapper.getCountByGroupName(name, (Integer) null, user.getId()).intValue() > 0) {
            throw new UEException("组合字典【" + name + "】已存在");
        }
        return this.pwddicMapper.insertGroup(name, upid, ppid, user.getId());
    }

    public List<Map<String, Object>> searchGroup(HttpSession session, String name, Integer offset, Integer limit) throws Exception {
        return this.pwddicMapper.searchGroup(name, offset, limit, DataRule.getRuleWhere(session, "t_pwd_group"));
    }

    public int searchGroupCount(HttpSession session, String name) throws Exception {
        return this.pwddicMapper.searchGroupCount(name, DataRule.getRuleWhere(session, "t_pwd_group"));
    }

    public void delGroup(HttpSession session, Integer id, Integer version) throws Exception {
        this.pwddicMapper.delGroup(id, version, DataRule.getRuleWhere(session, "t_pwd_group"));
    }

    public List<Map<String, Object>> getWebPwds() throws Exception {
        return this.pwddicMapper.getWebPwds();
    }
}
